parse

Function parse 

pub fn parse(source: &str) -> Result<SchemaFile, ParseError>
Parse a .ferriorm schema string into an AST.

Errors

Returns a ParseError if the source does not conform to the grammar.

Panics

Panics if the PEG grammar produces no top-level pair, which indicates a bug in the grammar definition.